@@ -41,7 +41,6 @@ struct _EphyDownload {
 
   WebKitDownload *download;
 
-  char *destination;
   char *content_type;
 
   gboolean show_notification;
@@ -444,16 +443,14 @@ ephy_download_do_download_action (EphyDownload           *download,
   switch ((action ? action : download->action)) {
     case EPHY_DOWNLOAD_ACTION_BROWSE_TO:
       LOG ("ephy_download_do_download_action: browse_to");
-      /* Must not use this action type under flatpak! */
-      ret = ephy_file_browse_to (destination, user_time,
-                                 EPHY_FILE_HELPERS_I_UNDERSTAND_I_MUST_NOT_USE_THIS_FUNCTION_UNDER_FLATPAK);
+      /* Must not use this action type under sandbox! */
+      ret = ephy_file_browse_to (destination, user_time);
       break;
     case EPHY_DOWNLOAD_ACTION_OPEN:
       LOG ("ephy_download_do_download_action: open");
       ret = ephy_file_launch_handler (destination, user_time);
-      if (!ret && !ephy_is_running_inside_flatpak ())
-        ret = ephy_file_browse_to (destination, user_time,
-                                   EPHY_FILE_HELPERS_I_UNDERSTAND_I_MUST_NOT_USE_THIS_FUNCTION_UNDER_FLATPAK);
+      if (!ret)
+        ret = ephy_file_browse_to (destination, user_time);
       break;
     case EPHY_DOWNLOAD_ACTION_NONE:
       LOG ("ephy_download_do_download_action: none");
@@ -697,7 +694,7 @@ download_created_destination_cb (WebKitDownload *wk_download,
   }
 
   if (!download->content_type ||
-      (download->content_type && !g_content_type_equals (download->content_type, content_type))) {
+      !g_content_type_equals (download->content_type, content_type)) {
     g_free (download->content_type);
     download->content_type = content_type;
     g_object_notify_by_pspec (G_OBJECT (download), obj_properties[PROP_CONTENT_TYPE]);
@@ -805,7 +802,6 @@ filename_suggested_cb (EphyDownload *download,
   GtkWidget *filechooser;
   WebKitDownload *webkit_download;
   WebKitURIResponse *response;
-  g_autofree gchar *sanitized_filename = NULL;
   g_autofree gchar *type_text = NULL;
   g_autofree gchar *from_text = NULL;
   g_autofree gchar *content_length = NULL;
@@ -828,7 +824,7 @@ filename_suggested_cb (EphyDownload *download,
   response = webkit_download_get_response (webkit_download);
 
   box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-  gtk_box_pack_start (GTK_BOX (message_area), box, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (message_area), box, FALSE, TRUE, 0);
 
   /* Type */
   content_length = g_format_size (webkit_uri_response_get_content_length (response));
@@ -836,22 +832,22 @@ filename_suggested_cb (EphyDownload *download,
   type_text = g_strdup_printf (_("Type: %s (%s)"), g_content_type_get_description (content_type), content_length);
   type_label = gtk_label_new (type_text);
   gtk_widget_set_margin_top (type_label, 12);
-  gtk_box_pack_start (GTK_BOX (box), type_label, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box), type_label, FALSE, TRUE, 0);
 
   /* From */
   from_text = g_strdup_printf (_("From: %s"), ephy_string_get_host_name (webkit_uri_response_get_uri (response)));
   from_label = gtk_label_new (from_text);
-  gtk_box_pack_start (GTK_BOX (box), from_label, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box), from_label, FALSE, TRUE, 0);
 
   /* Question */
   question_label = gtk_label_new (_("Where do you want to save the file?"));
   gtk_widget_set_margin_top (question_label, 12);
-  gtk_box_pack_start (GTK_BOX (box), question_label, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box), question_label, FALSE, TRUE, 0);
 
   /* File Chooser Button */
   filechooser = gtk_file_chooser_button_new (_("Save file"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (filechooser), g_settings_get_string (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_LAST_DOWNLOAD_DIRECTORY));
-  gtk_box_pack_start (GTK_BOX (box), filechooser, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box), filechooser, FALSE, TRUE, 0);
 
   gtk_widget_show_all (box);
 
@@ -887,9 +883,6 @@ ephy_download_new_internal (WebKitDownload *download)
   g_signal_connect_object (download, "notify::response",
                            G_CALLBACK (download_response_changed_cb),
                            ephy_download, 0);
-  g_signal_connect_object (download, "decide-destination",
-                           G_CALLBACK (download_decide_destination_cb),
-                           ephy_download, 0);
   g_signal_connect_object (download, "created-destination",
                            G_CALLBACK (download_created_destination_cb),
                            ephy_download, 0);
@@ -921,7 +914,11 @@ ephy_download_new (WebKitDownload *download)
 
   ephy_download = ephy_download_new_internal (download);
 
-  if (!ephy_is_running_inside_flatpak () && g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ASK_ON_DOWNLOAD)) {
+  g_signal_connect_object (download, "decide-destination",
+                           G_CALLBACK (download_decide_destination_cb),
+                           ephy_download, 0);
+
+  if (!ephy_is_running_inside_sandbox () && g_settings_get_boolean (EPHY_SETTINGS_WEB, EPHY_PREFS_WEB_ASK_ON_DOWNLOAD)) {
     g_signal_connect (ephy_download, "filename-suggested",
                       G_CALLBACK (filename_suggested_cb),
                       NULL);
